@@ -1,14 +1,15 @@
 #!/bin/sh
 echo 'name: gio
-version: 0.12.0
-id: gio-0.12.0-9ca9c782cb7305349c8967c058f44f91
+version: 0.12.3
+id: gio-0.12.3-f342b5f4ffd40d3a7b464b22b3f89f5f
 
 license: LGPL-2.1
 copyright: (c) 2001-2010 The Gtk2Hs Team
-maintainer: gtk2hs-users@sourceforge.net
+maintainer: gtk2hs-users@lists.sourceforge.net
 stability: stable
-homepage: http://www.haskell.org/gtk2hs/
+homepage: http://projects.haskell.org/gtk2hs/
 package-url:
+synopsis: Binding to the GIO.
 description: GIO is striving to provide a modern, easy-to-use VFS API that sits at the right level in the library stack.
              The goal is to overcome the shortcomings of GnomeVFS and provide an API that is
              so good that developers prefer it over raw POSIX calls.
@@ -30,27 +31,26 @@ exposed-modules: System.GIO System.GIO.Enums System.GIO.Types
                  System.GIO.Volumes.Drive System.GIO.Volumes.Mount
                  System.GIO.Volumes.Volume System.GIO.Volumes.VolumeMonitor
 hidden-modules: System.GIO.Signals
-import-dirs: /usr/local/lib/ghc/gio-0.12.0
-library-dirs: /usr/local/lib/ghc/gio-0.12.0 /usr/local/lib
-hs-libraries: HSgio-0.12.0
-extra-libraries: gio-2.0 gobject-2.0 gthread-2.0 gmodule-2.0
-                 glib-2.0 intl iconv
+trusted: False
+import-dirs: /usr/local/lib/ghc/gio-0.12.3
+library-dirs: /usr/local/lib/ghc/gio-0.12.3 /usr/local/lib
+hs-libraries: HSgio-0.12.3
+extra-libraries: gio-2.0 gobject-2.0 glib-2.0 intl iconv
 extra-ghci-libraries:
 include-dirs: /usr/local/include/glib-2.0
-              /usr/local/lib/glib-2.0/include
+              /usr/local/lib/glib-2.0/include /usr/local/include
 includes:
-depends: array-0.3.0.2-f538acad67d0b6696484da310d5949cf
-         base-4.3.1.0-ee15f259a627d341af7c80a17e8b0e66
-         bytestring-0.9.1.10-4e62762ee9b2a5d0cc5bc2fbaaeefd53
-         containers-0.4.0.0-f1307d32d8f4b51a1487c01f0997b6d9
-         glib-0.12.0-58f533cd92d47371ecb1bc085e466fee
-         haskell98-1.1.0.1-3ce559675b118e85a39def472ca9857c
-         mtl-2.0.1.0-3e464329054b7660133198d73c31aca5
+depends: array-0.4.0.0-4f6c2a594155b0b953c1cf0f54040f61
+         base-4.5.1.0-5b1c9d3d412ed227632edae6d2aca151
+         bytestring-0.9.2.1-3c5b69d9d36e3a0179d120b97025ab86
+         containers-0.4.2.1-efa59805336a77490296ae3897cecb87
+         glib-0.12.3.1-802d98cfe9a88c3ac80f8e30d4b86d4a
+         mtl-2.1.2-cf6082d8d4c6758d23401302efadd028
 hugs-options:
 cc-options:
-ld-options: -pthread
+ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-gio-0.12.0/html/gio.haddock
-haddock-html: /usr/local/share/doc/hs-gio-0.12.0/html
+haddock-interfaces: /usr/local/share/doc/hs-gio-0.12.3/html/gio.haddock
+haddock-html: /usr/local/share/doc/hs-gio-0.12.3/html
 ' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
